@@ -31,7 +31,8 @@ CONF = cfg.CONF
 LOG = logging.getLogger(__name__)
 
 
-def ensure_base_wiring_config(idl, ovs_idl, ovn_idl=None, routing_tables={}):
+def ensure_base_wiring_config(idl, ovs_idl, ovn_idl=None, routing_tables=None):
+    routing_tables = routing_tables or {}
     if CONF.exposing_method == constants.EXPOSE_METHOD_UNDERLAY:
         return _ensure_base_wiring_config_underlay(idl, ovs_idl,
                                                    routing_tables)
@@ -55,6 +56,8 @@ def _ensure_base_wiring_config_underlay(idl, ovs_idl, routing_tables):
             continue
         ovn_bridge_mappings[network] = bridge
 
+        linux_net.ensure_bridge(bridge)
+
         linux_net.ensure_routing_table_for_bridge(
             routing_tables, bridge, CONF.bgp_vrf_table_id)
         vlan_tags = idl.get_network_vlan_tag_by_network_name(network)
